# WATA

A collection of various processing tools.


## PointCloudProcess
- cut_pcd
- filter_points
- get_points
- pcd2bin
- cartesian_to_spherical
- get_v_channel_from_pcd
- get_h_channel_from_pcd
- points_in_boxes
- save_pcd
- array_to_structured_array
- structured_array_to_array
- saveTanwayRoadPCDBinaryCompressed
- get_anno_from_tanwayjson
- points_to_o3d_model
- save_o3d_camera_parameters
- show_pcd
- show_pcd_from_points
- show_pcd_from_points_by_open3d
- show_pcd_from_points_by_matplotlib
- show_pcd_from_points_by_qtopengl
- add_boxes_by_open3d
- add_boxes_by_matplotlib
- show_o3d_model

## GeoProcess

- WGS84_to_GCJ02
- WGS84_to_BD09
- WGS84_to_UTM
- GCJ02_to_WGS84
- GCJ02_to_BD09
- BD09_to_GCJ02
- BD09_to_WGS84
- UTM_to_WGS84


## Maths
- point_in_polygon
- xy2rt
- rt2xy
- xyz2rtp
- rtp2xyz

## FileProcess
- load_file
- save_file
- file_tree
- mkdir_if_not_exist

## ImageProcess
- show_img
- img2video
- video2img

